@@ -1,12 +1,12 @@
 from dataflows import Flow, concatenate, add_computed_field, \
-    unpivot, set_primary_key, PackageWrapper, set_type
+    unpivot, set_primary_key, PackageWrapper, set_type, validate
 from dataflows.base.schema_validator import ignore
 
 from ...core import BaseDataGenusProcessor
 from .analyzers import TaxonomiesDGP, MappingDGP
 from ...config.consts import CONFIG_MODEL_EXTRA_FIELDS, CONFIG_MODEL_MAPPING,\
             CONFIG_TAXONOMY_CT, CONFIG_CONSTANTS, RESOURCE_NAME,\
-            CONFIG_PRIMARY_KEY, CONFIG_TAXONOMY_ID
+            CONFIG_PRIMARY_KEY, CONFIG_TAXONOMY_ID, CONFIG_TAXONOMY_MISSING_VALUES
 
 
 class TransformDGP(BaseDataGenusProcessor):
@@ -95,7 +95,10 @@ class TransformDGP(BaseDataGenusProcessor):
                                     field['type'] = entry['dataType']
                                 field.update(entry.get('options', {}))
                                 break
-                    field.update(field.pop('options', {}))
+                    field.update(field.get('options', {}))
+
+            # Missing Values
+            schema['missingValues'] = self.config[CONFIG_TAXONOMY_MISSING_VALUES]
 
             # Our own additions
             descriptor['taxonomyId'] = self.config[CONFIG_TAXONOMY_ID]
@@ -127,8 +130,10 @@ class TransformDGP(BaseDataGenusProcessor):
                 ct = mf.get('columnType')
                 if ct is not None:
                     fieldOptions[ct] = dataTypes.get(ct, {})
+                    fieldOptions[ct].update(mf.get('options', {}))
             steps = [
                 self.create_fdp(),
+                validate(on_error=ignore),
                 add_computed_field([
                     dict(
                         operation='constant',
